pub fn hex_push(blob: &[u8]) -> StringExpand description
Function to get a hexadecimal representation from bytes Thanks to: https://newbedev.com/how-do-i-convert-a-string-to-hex-in-rust
pub fn hex_push(blob: &[u8]) -> StringFunction to get a hexadecimal representation from bytes Thanks to: https://newbedev.com/how-do-i-convert-a-string-to-hex-in-rust