pub fn parse_gmsa(processed_aces: &mut Vec<AceTemplate>, user: &mut User)Expand description
Function to check the user can read Service Account password
pub fn parse_gmsa(processed_aces: &mut Vec<AceTemplate>, user: &mut User)Function to check the user can read Service Account password