pub struct MaskFlags(/* private fields */);Implementations
Sourceimpl MaskFlags
impl MaskFlags
pub const SET_GENERIC_READ: Self
pub const SET_GENERIC_WRITE: Self
pub const SET_GENERIC_EXECUTE: Self
pub const SET_GENERIC_ALL: Self
pub const GENERIC_READ: Self
pub const GENERIC_WRITE: Self
pub const GENERIC_EXECUTE: Self
pub const GENERIC_ALL: Self
pub const MAXIMUM_ALLOWED: Self
pub const ACCESS_SYSTEM_SECURITY: Self
pub const SYNCHRONIZE: Self
pub const WRITE_OWNER: Self
pub const WRITE_DACL: Self
pub const READ_CONTROL: Self
pub const DELETE: Self
pub const ADS_RIGHT_DS_CONTROL_ACCESS: Self
pub const ADS_RIGHT_DS_CREATE_CHILD: Self
pub const ADS_RIGHT_DS_DELETE_CHILD: Self
pub const ADS_RIGHT_DS_READ_PROP: Self
pub const ADS_RIGHT_DS_WRITE_PROP: Self
pub const ADS_RIGHT_DS_SELF: Self
pub const MANAGE_CA: Self
pub const MANAGE_CERTIFICATES: Self
Sourceimpl MaskFlags
impl MaskFlags
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.