Module common

Module common 

Functions

add_affected_computers
This function pushes computer SIDs into the domain’s GPO changes v2
add_affected_computers_for_ou
This function pushes computer SIDs into GPO changes for each OU
add_childobjects_members
This function is to push user SID in ChildObjects v2
add_childobjects_members_for_ou
This function is to push user SID in ChildObjects for Ou v2
add_contained_by_for
This function pushes user SID into ChildObjects for Ou v2
add_default_groups
Function to add default groups https://github.com/fox-it/BloodHound.py/blob/645082e3462c93f31b571db945cde1fd7b837fb9/bloodhound/enumeration/memberships.py#L411
add_default_users
Function to add default user https://github.com/fox-it/BloodHound.py/blob/645082e3462c93f31b571db945cde1fd7b837fb9/bloodhound/enumeration/memberships.py#L411
add_trustdomain
This function push trust domain values in domain
add_type_for_ace
This function checks PrincipalSID for all ACEs and adds the PrincipalType (“Group”, “User”, “Computer”) v2
add_type_for_allowtedtoact
This function checks PrincipalSID for all AllowedToAct objects and adds the PrincipalType (“Group”, “User”, “Computer”) v2
get_name_from_full_distinguishedname
Function to get name from DN
replace_fqdn_by_sid
This function replaces FQDN by SID in users’ SPNTargets or computers’ AllowedToDelegate
replace_guid_gplink
This function checks GUID for all Gplinks and replaces them with the correct GUIDs
replace_sid_members
This function checks and replaces object names by SIDs in group members v2