pub struct Error { /* private fields */ }Expand description
RustHound error’s type
Implementations
Sourceimpl Error
impl Error
Sourcepub fn new(kind: Kind) -> Error
pub fn new(kind: Kind) -> Error
Construct an error from scratch
You can chain this method to with, as shown below.
Error::new(Kind::Other).with()pub fn desc<D: Into<String>>(self, desc: D) -> Error
pub fn new_login() -> Error
pub fn new_host() -> Error
pub fn new_ldap_error(error: LdapError) -> Error
Sourcepub fn find_source<E: StdError + 'static>(&self) -> Option<&E>
pub fn find_source<E: StdError + 'static>(&self) -> Option<&E>
Backtrace error source to find a cause matching given type