Functions
- add_
affected_ computers - This function pushes computer SIDs into the domain’s GPO changes v2
- add_
affected_ computers_ for_ ou - This function pushes computer SIDs into GPO changes for each OU
- add_
childobjects_ members - This function is to push user SID in ChildObjects v2
- add_
childobjects_ members_ for_ ou - This function is to push user SID in ChildObjects for Ou v2
- add_
contained_ by_ for - This function pushes user SID into ChildObjects for Ou v2
- add_
default_ groups - Function to add default groups https://github.com/fox-it/BloodHound.py/blob/645082e3462c93f31b571db945cde1fd7b837fb9/bloodhound/enumeration/memberships.py#L411
- add_
default_ users - Function to add default user https://github.com/fox-it/BloodHound.py/blob/645082e3462c93f31b571db945cde1fd7b837fb9/bloodhound/enumeration/memberships.py#L411
- add_
trustdomain - This function push trust domain values in domain
- add_
type_ for_ ace - This function checks PrincipalSID for all ACEs and adds the PrincipalType (“Group”, “User”, “Computer”) v2
- add_
type_ for_ allowtedtoact - This function checks PrincipalSID for all AllowedToAct objects and adds the PrincipalType (“Group”, “User”, “Computer”) v2
- get_
name_ from_ full_ distinguishedname - Function to get name from DN
- replace_
fqdn_ by_ sid - This function replaces FQDN by SID in users’ SPNTargets or computers’ AllowedToDelegate
- replace_
guid_ gplink - This function checks GUID for all Gplinks and replaces them with the correct GUIDs
- replace_
sid_ members - This function checks and replaces object names by SIDs in group members v2