This function pushes computer SIDs into the domain’s GPO changes v2
This function pushes computer SIDs into GPO changes for each OU
This function is to push user SID in ChildObjects v2
This function is to push user SID in ChildObjects for Ou v2
This function pushes user SID into ChildObjects for Ou v2
This function push trust domain values in domain
This function checks PrincipalSID for all ACEs and adds the PrincipalType (“Group”, “User”, “Computer”) v2
This function checks PrincipalSID for all AllowedToAct objects and adds the PrincipalType (“Group”, “User”, “Computer”) v2
Function to get name from DN
This function replaces FQDN by SID in users’ SPNTargets or computers’ AllowedToDelegate
This function checks GUID for all Gplinks and replaces them with the correct GUIDs
This function checks and replaces object names by SIDs in group members v2