Run a LDAP enumeration and parse results
This module will prepare your connection and request the LDAP server to retrieve all the information needed to create the json files.
rusthound sends only one request to the LDAP server, if the result of this one is higher than the limit of the LDAP server limit it will be split in several requests to avoid having an error 4 (LDAP_SIZELIMIT_EXCEED).
Example in rust
let search = ldap_search(...)Functions
- get_
all_ naming_ contexts - (Not needed yet) Get all namingContext for DC
- ldap_
search - Function to request all AD values.
- prepare_
ldap_ dc - Function to prepare LDAP DC from DOMAIN.LOCAL